/* 
   (c) Copyright 2001-2002  convergence integrated media GmbH.
   (c) Copyright 2002-2005  convergence GmbH.

   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <stdio.h>
#include <stdlib.h>

#include "lite_internal.h"

#include "util.h"
#include "image.h"

D_DEBUG_DOMAIN( Lite_Image, "LiTE/Image", "LiteImage");

struct _LiteImage {
     LiteBox           box;

     int               width, height;

     IDirectFBSurface *surface;
};


static void draw_image (LiteBox *box, const DFBRegion *region, DFBBoolean clear);
static void destroy_image (LiteBox *box);

LiteImage *lite_new_image (LiteBox *parent, int x, int y, int width, int height)
{
     LiteImage *image;

     image = calloc (1, sizeof(LiteImage));

     image->box.parent = parent;

     image->box.rect.x = x;
     image->box.rect.y = y;
     image->box.rect.w = width;
     image->box.rect.h = height;

     if (lite_init_box (LITE_BOX (image))) {
          free (image);
          return NULL;
     }

     image->box.Draw    = draw_image;
     image->box.Destroy = destroy_image;

     return image;
}

DFBResult lite_load_image (LiteImage *image, const char *filename)
{
     DFBResult res;
     if (!filename || !image)
          return DFB_INVARG;

     res = lite_util_load_image (filename, DSPF_UNKNOWN, &image->surface,
                               &image->width, &image->height, NULL);
     if(res != DFB_OK)
          return res;

     return lite_update_box (LITE_BOX (image), NULL);

}


/* file internals */

static void destroy_image (LiteBox *box)
{
     LiteImage *image = LITE_IMAGE (box);

     if (!image)
          return;

     if (image->surface)
          image->surface->Release (image->surface);

     lite_destroy_box (box);
}

static void draw_image (LiteBox *box, const DFBRegion *region, DFBBoolean clear)
{
     LiteImage        *image   = LITE_IMAGE (box);
     IDirectFBSurface *surface = box->surface;

     surface->SetClip (surface, region);

     if (image->surface) {
          surface->SetBlittingFlags (surface, DSBLIT_BLEND_ALPHACHANNEL);
          surface->StretchBlit (surface, image->surface, NULL, NULL);
     }
     else if (clear)
          lite_clear_box (box, region);
}
